@@ -160,13 +160,18 @@ func Completion(cmd *cobra.Command, arg string) error {
 
 // argsToFiles returns the file name from the argument.
 func argsToFiles(args []string) []string {
-	var files []string
+	files := make([]string, 0, len(args))
 	for _, arg := range args {
 		argFiles, err := filepath.Glob(arg)
 		if err != nil {
 			continue
 		}
-		files = append(files, argFiles...)
+		if len(argFiles) > 0 {
+			files = append(files, argFiles...)
+			continue
+		}
+		// fallback to the original argument.
+		files = append(files, arg)
 	}
 	// If filePath.Glob does not match,
 	// return argument to return correct error
@@ -356,7 +361,7 @@ func openFile(fileName string) (*os.File, error) {
 	return os.Open(fileName)
 }
 
-// copyOutput just outputs the input (standard input if there is no first file).
+// copyOutput outputs the content of the specified file or standard input.
 func copyOutput(args []string) error {
 	files := argsToFiles(args)
 	fileName := ""
@@ -508,6 +513,10 @@ func init() {
 	rootCmd.PersistentFlags().BoolP("hide-other-section", "", false, "hide other section")
 	_ = viper.BindPFlag("general.HideOtherSection", rootCmd.PersistentFlags().Lookup("hide-other-section"))
 
+	rootCmd.PersistentFlags().IntP("notify-eof", "", 0, "notify at the end of the file")
+	_ = viper.BindPFlag("NotifyEOF", rootCmd.PersistentFlags().Lookup("notify-eof"))
+	rootCmd.PersistentFlags().Lookup("notify-eof").NoOptDefVal = "1"
+
 	// Config
 	rootCmd.PersistentFlags().BoolP("quit-if-one-screen", "F", false, "quit if the output fits on one screen")
 	_ = viper.BindPFlag("QuitSmall", rootCmd.PersistentFlags().Lookup("quit-if-one-screen"))
