@@ -12,6 +12,8 @@ import (
 	"strings"
 	"sync/atomic"
 	"time"
+
+	"golang.org/x/term"
 )
 
 // toggleWrapMode toggles wrapMode each time it is called.
@@ -182,10 +184,10 @@ func (root *Root) watchControl() {
 
 // searchGo will go to the line with the matching term after searching.
 // Jump by section if JumpTargetSection is true.
-func (root *Root) searchGo(ctx context.Context, lN int) {
+func (root *Root) searchGo(ctx context.Context, lN int, searcher Searcher) {
 	root.resetSelect()
 	root.Doc.lastSearchLN = lN
-	x := root.searchXPos(lN)
+	x := root.searchXPos(lN, searcher)
 	if root.Doc.jumpTargetSection {
 		root.Doc.searchGoSection(ctx, lN, x)
 		return
@@ -244,8 +246,8 @@ func (root *Root) goLineNumber(lN int) {
 	root.setMessagef("Moved to line %d", lN+1)
 }
 
-// markNext moves to the next mark.
-func (root *Root) markNext(context.Context) {
+// nextMark moves to the next mark.
+func (root *Root) nextMark(context.Context) {
 	if len(root.Doc.marked) == 0 {
 		return
 	}
@@ -258,8 +260,8 @@ func (root *Root) markNext(context.Context) {
 	root.goLineNumber(root.Doc.marked[root.Doc.markedPoint])
 }
 
-// markPrev moves to the previous mark.
-func (root *Root) markPrev(context.Context) {
+// prevMark moves to the previous mark.
+func (root *Root) prevMark(context.Context) {
 	if len(root.Doc.marked) == 0 {
 		return
 	}
@@ -274,15 +276,16 @@ func (root *Root) markPrev(context.Context) {
 
 // addMark marks the current line number.
 func (root *Root) addMark(context.Context) {
-	lN := min(root.Doc.topLN+root.Doc.firstLine(), root.Doc.BufEndNum())
+	lN := root.firstBodyLine()
 	root.Doc.marked = remove(root.Doc.marked, lN)
 	root.Doc.marked = append(root.Doc.marked, lN)
+	root.Doc.markedPoint++
 	root.setMessagef("Marked to line %d", lN-root.Doc.firstLine()+1)
 }
 
 // removeMark removes the current line number from the mark.
 func (root *Root) removeMark(context.Context) {
-	lN := root.Doc.topLN + root.Doc.firstLine()
+	lN := root.firstBodyLine()
 	marked := remove(root.Doc.marked, lN)
 	if len(root.Doc.marked) == len(marked) {
 		root.setMessagef("Not marked line %d", lN-root.Doc.firstLine()+1)
@@ -292,6 +295,12 @@ func (root *Root) removeMark(context.Context) {
 	root.setMessagef("Remove the mark at line %d", lN-root.Doc.firstLine()+1)
 }
 
+// firstBodyLine returns the first line number of the body.
+func (root *Root) firstBodyLine() int {
+	ln := root.scr.lineNumber(root.Doc.headerHeight + root.Doc.sectionHeaderHeight)
+	return ln.number
+}
+
 // removeAllMark removes all marks.
 func (root *Root) removeAllMark(context.Context) {
 	root.Doc.marked = nil
@@ -327,6 +336,7 @@ func (root *Root) setSkipLines(input string) {
 	}
 
 	root.Doc.SkipLines = num
+	root.Doc.columnWidths = nil
 	root.setMessagef("Set skip lines %d", num)
 }
 
@@ -360,31 +370,57 @@ func specifyOnScreen(input string, max int) (int, error) {
 // It will return when you exit the shell.
 func (root *Root) suspend(context.Context) {
 	log.Println("Suspend")
-	shell := os.Getenv("SHELL")
-	if err := root.shellSuspendResume(shell); err != nil {
-		root.setMessageLog(err.Error())
-	}
-	log.Println("Resume")
-}
-
-func (root *Root) shellSuspendResume(shell string) error {
 	if err := root.Screen.Suspend(); err != nil {
-		return err
+		root.setMessageLog(err.Error())
+		return
 	}
-	defer func() error {
-		return root.Screen.Resume()
+	defer func() {
+		log.Println("Resume")
+		if err := root.Screen.Resume(); err != nil {
+			log.Println(err)
+		}
 	}()
 
-	fmt.Println("suspended ov")
-	if shell == "" {
-		if runtime.GOOS == "windows" {
-			shell = "CMD.EXE"
-		} else {
-			shell = "/bin/sh"
+	subshell := os.Getenv("OV_SUBSHELL")
+	// If the OS is something other than Windows
+	// or if the environment variable Subshell is not set,
+	// suspend with sigstop.
+	if runtime.GOOS != "windows" && subshell != "1" {
+		fmt.Println("suspended ov (use 'fg' to resume)")
+		if err := suspendProcess(); err != nil {
+			root.setMessageLog(err.Error())
 		}
+		return
 	}
+
+	// If the OS is Windows,
+	// or if the environment variable Subshell is set,
+	// start the subshell.
+	fmt.Println("suspended ov (use 'exit' to resume)")
+	shell := os.Getenv("SHELL")
+	if err := root.subShell(shell); err != nil {
+		root.setMessageLog(err.Error())
+	}
+}
+
+func (root *Root) subShell(shell string) error {
+	if shell == "" {
+		shell = getShell()
+	}
+
+	stdin := os.Stdin
+	if !term.IsTerminal(int(os.Stdin.Fd())) {
+		// Use TTY as stdin when the current stdin is not a terminal.
+		tty, err := getTty()
+		if err != nil {
+			return fmt.Errorf("failed to open tty: %w", err)
+		}
+		defer tty.Close()
+		stdin = tty
+	}
+
 	c := exec.Command(shell, "-l")
-	c.Stdin = os.Stdin
+	c.Stdin = stdin
 	c.Stdout = os.Stdout
 	c.Stderr = os.Stderr
 	if err := c.Run(); err != nil {
@@ -394,6 +430,20 @@ func (root *Root) shellSuspendResume(shell string) error {
 	return nil
 }
 
+func getShell() string {
+	if runtime.GOOS == "windows" {
+		return "CMD.EXE"
+	}
+	return "/bin/sh"
+}
+
+func getTty() (*os.File, error) {
+	if runtime.GOOS == "windows" {
+		return os.Open("CONIN$")
+	}
+	return os.Open("/dev/tty")
+}
+
 // setViewMode switches to the preset display mode.
 // Set header lines and columnMode together.
 func (root *Root) setViewMode(ctx context.Context, modeName string) {
@@ -402,21 +452,22 @@ func (root *Root) setViewMode(ctx context.Context, modeName string) {
 		root.setMessage(err.Error())
 		return
 	}
-
-	root.Doc.general = mergeGeneral(root.Doc.general, c)
-	root.Doc.regexpCompile()
-	root.Doc.ClearCache()
+	m := root.Doc
+	m.general = mergeGeneral(m.general, c)
+	m.conv = m.converterType(m.general.Converter)
+	m.regexpCompile()
+	m.ClearCache()
 	root.ViewSync(ctx)
 	// Set caption.
-	if root.Doc.general.Caption != "" {
-		root.Doc.Caption = root.Doc.general.Caption
+	if m.general.Caption != "" {
+		m.Caption = m.general.Caption
 	}
 	root.setMessagef("Set mode %s", modeName)
 }
 
 // modeConfig returns the configuration of the specified mode.
 func (root *Root) modeConfig(modeName string) (general, error) {
-	if modeName == "general" {
+	if modeName == nameGeneral {
 		return root.General, nil
 	}
 
@@ -427,9 +478,49 @@ func (root *Root) modeConfig(modeName string) (general, error) {
 	return c, nil
 }
 
+// setConverter sets the converter type.
+func (root *Root) setConverter(ctx context.Context, name string) {
+	m := root.Doc
+	if m.general.Converter == name {
+		return
+	}
+	m.general.Converter = name
+	m.conv = m.converterType(name)
+	m.ClearCache()
+	root.ViewSync(ctx)
+}
+
+// alignFormat sets converter type to align.
+func (root *Root) alignFormat(ctx context.Context) {
+	if root.Doc.Converter == convAlign {
+		root.esFormat(ctx)
+		return
+	}
+	root.setConverter(ctx, convAlign)
+	root.setMessage("Set align mode")
+}
+
+// rawFormat sets converter type to raw.
+func (root *Root) rawFormat(ctx context.Context) {
+	if root.Doc.Converter == convRaw {
+		root.esFormat(ctx)
+		return
+	}
+	root.setConverter(ctx, convRaw)
+	root.setMessage("Set raw mode")
+}
+
+// esFormat sets converter type to es.
+func (root *Root) esFormat(ctx context.Context) {
+	root.setConverter(ctx, convEscaped)
+	root.setMessage("Set es mode")
+}
+
 // setDelimiter sets the delimiter string.
 func (root *Root) setDelimiter(input string) {
 	root.Doc.setDelimiter(input)
+	root.Doc.optimalCursor(root.scr, root.Doc.columnCursor)
+	root.Doc.columnCursor = max(root.Doc.columnStart, root.Doc.columnCursor)
 	root.setMessagef("Set delimiter %s", input)
 }
 
@@ -655,22 +746,23 @@ func (root *Root) updateEndNum() {
 	root.Screen.Sync()
 }
 
-// follow updates the document in follow mode.
-func (root *Root) follow(ctx context.Context) {
-	if root.General.FollowAll {
-		root.followAll(ctx)
-	}
+// updateLatestNum updates the last line number in follow mode.
+func (root *Root) updateLatestNum() bool {
 	num := root.Doc.BufEndNum()
 	if root.Doc.latestNum == num {
-		return
+		return false
 	}
 	root.skipDraw = false
-	if root.Doc.FollowSection {
-		root.tailSection(ctx)
-	} else {
+	root.Doc.latestNum = num
+	return true
+}
+
+// follow monitors and switches the document update
+// in follow mode.
+func (root *Root) follow(ctx context.Context) {
+	if root.updateLatestNum() {
 		root.TailSync(ctx)
 	}
-	root.Doc.latestNum = num
 }
 
 // followAll monitors and switches all document updates
@@ -683,6 +775,8 @@ func (root *Root) followAll(ctx context.Context) {
 	current := root.CurrentDoc
 	root.mu.RLock()
 	for n, doc := range root.DocList {
+		doc.width = root.scr.vWidth - root.scr.startX
+		doc.height = root.scr.vHeight - (statusLine + doc.headerHeight)
 		if doc.latestNum != doc.BufEndNum() {
 			current = n
 		}
@@ -692,6 +786,17 @@ func (root *Root) followAll(ctx context.Context) {
 	if root.CurrentDoc != current {
 		root.switchDocument(ctx, current)
 	}
+	if root.updateLatestNum() {
+		root.TailSync(ctx)
+	}
+}
+
+// followSection monitors and switches the document update
+// in follow section mode.
+func (root *Root) followSection(ctx context.Context) {
+	if root.updateLatestNum() {
+		root.tailSection(ctx)
+	}
 }
 
 // Cancel follow mode and follow all mode.
@@ -721,3 +826,49 @@ func (root *Root) bottomSectionLN(ctx context.Context) int {
 	}
 	return lN - (root.Doc.topLN + root.Doc.firstLine() - root.Doc.SectionStartPosition)
 }
+
+// ShrinkColumn shrinks the specified column.
+func (root *Root) ShrinkColumn(ctx context.Context, cursor int) error {
+	return root.Doc.shrinkColumn(cursor, true)
+}
+
+// ExpandColumn expands the specified column.
+func (root *Root) ExpandColumn(ctx context.Context, cursor int) error {
+	return root.Doc.shrinkColumn(cursor, false)
+}
+
+// toggleColumnShrink shrinks or expands the current cursor column.
+func (root *Root) toggleColumnShrink(ctx context.Context) {
+	cursor := root.Doc.columnCursor
+	shrink, err := root.Doc.isColumnShrink(cursor)
+	if err != nil {
+		root.setMessage(err.Error())
+	}
+	if err := root.Doc.shrinkColumn(cursor, !shrink); err != nil {
+		root.setMessage(err.Error())
+	}
+}
+
+// isColumnShrink returns whether the specified column is shrink.
+func (m *Document) isColumnShrink(cursor int) (bool, error) {
+	if m.Converter != convAlign {
+		return false, ErrNotAlignMode
+	}
+	if cursor < 0 || cursor >= len(m.alignConv.columnAttrs) {
+		return false, ErrNoColumnSelected
+	}
+	return m.alignConv.columnAttrs[cursor].shrink, nil
+}
+
+// shinkColumn shrinks or expands the specified column.
+func (m *Document) shrinkColumn(cursor int, shrink bool) error {
+	if m.Converter != convAlign {
+		return ErrNotAlignMode
+	}
+	if cursor < 0 || cursor >= len(m.alignConv.columnAttrs) {
+		return ErrNoColumnSelected
+	}
+	m.alignConv.columnAttrs[cursor].shrink = shrink
+	m.ClearCache()
+	return nil
+}
