@@ -2,7 +2,6 @@ package oviewer
 
 import (
 	"context"
-	"os"
 	"path/filepath"
 	"reflect"
 	"testing"
@@ -204,7 +203,6 @@ func Test_position(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 			if got := calculatePosition(tt.args.str, tt.args.height); got != tt.want {
@@ -375,7 +373,6 @@ func Test_jumpPosition(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 			got, got1 := jumpPosition(tt.args.str, tt.args.height)
@@ -803,7 +800,7 @@ func TestRoot_searchGo(t *testing.T) {
 			root.Doc.jumpTargetSection = tt.fields.jumpTargetSection
 			root.setSectionDelimiter(tt.fields.sectionDelimiter)
 			root.Doc.SectionHeader = true
-			root.searchGo(ctx, tt.args.lN)
+			root.searchGo(ctx, tt.args.lN, root.searcher)
 			if root.Doc.topLN != tt.want {
 				t.Errorf("searchGo() = %v, want %v", root.Doc.topLN, tt.want)
 			}
@@ -938,7 +935,7 @@ func TestRoot_ColumnDelimiterWrapMode(t *testing.T) {
 				wrapMode:     false,
 			},
 			want: want{
-				x:            2,
+				x:            10,
 				columnCursor: 1,
 				wrapMode:     true,
 			},
@@ -1061,24 +1058,29 @@ func TestRoot_Mark(t *testing.T) {
 	}()
 	root := rootFileReadHelper(t, filepath.Join(testdata, "test3.txt"))
 	t.Run("TestMark", func(t *testing.T) {
+		root.prepareScreen()
 		ctx := context.Background()
 		root.Doc.topLN = 1
+		root.draw(ctx)
 		root.addMark(ctx)
 		if !reflect.DeepEqual(root.Doc.marked, []int{1}) {
 			t.Errorf("addMark() = %#v, want %#v", root.Doc.marked, []int{1})
 		}
 		root.Doc.topLN = 10
+		root.draw(ctx)
 		root.addMark(ctx)
 		if !reflect.DeepEqual(root.Doc.marked, []int{1, 10}) {
 			t.Errorf("addMark() = %#v, want %#v", root.Doc.marked, []int{1, 10})
 		}
 		root.Doc.topLN = 1
+		root.draw(ctx)
 		root.removeMark(ctx)
 		if !reflect.DeepEqual(root.Doc.marked, []int{10}) {
 			t.Errorf("removeAllMark() = %#v, want %#v", root.Doc.marked, []int{10})
 		}
 		root.removeMark(ctx)
 		root.Doc.topLN = 2
+		root.draw(ctx)
 		root.addMark(ctx)
 		if !reflect.DeepEqual(root.Doc.marked, []int{10, 2}) {
 			t.Errorf("addMark() = %#v, want %#v", root.Doc.marked, []int{10, 2})
@@ -1090,7 +1092,7 @@ func TestRoot_Mark(t *testing.T) {
 	})
 }
 
-func TestRoot_markNext(t *testing.T) {
+func TestRoot_nextMark(t *testing.T) {
 	tcellNewScreen = fakeScreen
 	defer func() {
 		tcellNewScreen = tcell.NewScreen
@@ -1121,10 +1123,10 @@ func TestRoot_markNext(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			root.markNext(context.Background()) // no marked
+			root.nextMark(context.Background()) // no marked
 			root.Doc.marked = []int{1, 3, 5}
 			root.Doc.markedPoint = tt.markedPoint
-			root.markNext(context.Background())
+			root.nextMark(context.Background())
 			if root.Doc.topLN != tt.wantLine {
 				t.Errorf("got line %d, want line %d", root.Doc.topLN, tt.wantLine)
 			}
@@ -1132,7 +1134,7 @@ func TestRoot_markNext(t *testing.T) {
 	}
 }
 
-func TestRoot_markPrev(t *testing.T) {
+func TestRoot_prevMark(t *testing.T) {
 	tcellNewScreen = fakeScreen
 	defer func() {
 		tcellNewScreen = tcell.NewScreen
@@ -1163,10 +1165,10 @@ func TestRoot_markPrev(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			root.markPrev(context.Background()) // no marked
+			root.prevMark(context.Background()) // no marked
 			root.Doc.marked = []int{1, 3, 5}
 			root.Doc.markedPoint = tt.markedPoint
-			root.markPrev(context.Background())
+			root.prevMark(context.Background())
 			if root.Doc.topLN != tt.wantLine {
 				t.Errorf("got line %d, want line %d", root.Doc.topLN, tt.wantLine)
 			}
@@ -1245,7 +1247,7 @@ func TestRoot_modeConfig(t *testing.T) {
 		{
 			name: "testModeConfig general",
 			args: args{
-				modeName: "general",
+				modeName: nameGeneral,
 			},
 			want:    general{},
 			wantErr: false,
@@ -1281,17 +1283,6 @@ func TestRoot_modeConfig(t *testing.T) {
 	}
 }
 
-func TestRoot_suspend(t *testing.T) {
-	root := rootHelper(t)
-	shell := os.Getenv("SHELL")
-	if got := root.shellSuspendResume(shell); got != nil {
-		t.Errorf("shellSuspendResume() = %v, want %v", got, nil)
-	}
-	if got := root.shellSuspendResume(""); got != nil {
-		t.Errorf("shellSuspendResume() = %v, want %v", got, nil)
-	}
-}
-
 func TestRoot_follow(t *testing.T) {
 	tcellNewScreen = fakeScreen
 	defer func() {
@@ -1385,7 +1376,7 @@ func TestRoot_followAll(t *testing.T) {
 			ctx := context.Background()
 			root.prepareScreen()
 			root.everyUpdate(ctx)
-			root.follow(ctx)
+			root.followAll(ctx)
 			if root.Doc.topLN != tt.want {
 				t.Errorf("follow() topLN = %v, want %v", root.Doc.topLN, tt.want)
 			}
@@ -1505,3 +1496,122 @@ func TestRoot_tailSection(t *testing.T) {
 		})
 	}
 }
+
+func TestRoot_setConverter(t *testing.T) {
+	tcellNewScreen = fakeScreen
+	defer func() {
+		tcellNewScreen = tcell.NewScreen
+	}()
+	type args struct {
+		name string
+	}
+	tests := []struct {
+		name string
+		args args
+		want Converter
+	}{
+		{
+			name: "testSetConverterEscape",
+			args: args{
+				name: convEscaped,
+			},
+			want: newESConverter(),
+		},
+		{
+			name: "testSetConverterRaw",
+			args: args{
+				name: convRaw,
+			},
+			want: newRawConverter(),
+		},
+		{
+			name: "testSetConverterAlign",
+			args: args{
+				name: convAlign,
+			},
+			want: newAlignConverter(false),
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			root := rootHelper(t)
+			ctx := context.Background()
+			root.setConverter(ctx, tt.args.name)
+			got := root.Doc.conv
+			if !reflect.DeepEqual(got, tt.want) {
+				t.Errorf("setConverter() = %v, want %v", got, tt.want)
+			}
+		})
+	}
+}
+
+func TestRoot_ShrinkColumn(t *testing.T) {
+	tcellNewScreen = fakeScreen
+	defer func() {
+		tcellNewScreen = tcell.NewScreen
+	}()
+	type fields struct {
+		fileName  string
+		converter string
+	}
+	type args struct {
+		cursor int
+		shrink bool
+	}
+	tests := []struct {
+		name    string
+		fields  fields
+		args    args
+		wantErr bool
+	}{
+		{
+			name: "testShrinkColumn",
+			fields: fields{
+				fileName:  filepath.Join(testdata, "MOCK_DATA.csv"),
+				converter: convAlign,
+			},
+			args: args{
+				cursor: 0,
+				shrink: true,
+			},
+			wantErr: false,
+		},
+		{
+			name: "testShrinkColumnFalse",
+			fields: fields{
+				fileName:  filepath.Join(testdata, "MOCK_DATA.csv"),
+				converter: convEscaped,
+			},
+			args: args{
+				cursor: 0,
+				shrink: true,
+			},
+			wantErr: true,
+		},
+		{
+			name: "testShrinkColumnOver",
+			fields: fields{
+				fileName:  filepath.Join(testdata, "MOCK_DATA.csv"),
+				converter: convAlign,
+			},
+			args: args{
+				cursor: 20,
+				shrink: true,
+			},
+			wantErr: true,
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			root := rootFileReadHelper(t, tt.fields.fileName)
+			ctx := context.Background()
+			root.prepareScreen()
+			root.Doc.Converter = tt.fields.converter
+			root.Doc.ColumnDelimiter = ","
+			root.prepareDraw(ctx)
+			if err := root.Doc.shrinkColumn(tt.args.cursor, tt.args.shrink); (err != nil) != tt.wantErr {
+				t.Errorf("Root.ShrinkColumn() error = %v, wantErr %v", err, tt.wantErr)
+			}
+		})
+	}
+}
