@@ -12,10 +12,12 @@ func NewConfig() Config {
 			Background: "gray",
 		},
 		StyleOverStrike: OVStyle{
-			Bold: true,
+			Bold:           true,
+			UnderlineStyle: "3",
 		},
 		StyleOverLine: OVStyle{
-			Underline: true,
+			Underline:      true,
+			UnderlineStyle: "2",
 		},
 		StyleLineNumber: OVStyle{
 			Bold: true,
@@ -59,8 +61,9 @@ func NewConfig() Config {
 		},
 		Prompt: OVPromptConfig{
 			Normal: OVPromptConfigNormal{
-				ShowFilename: true,
-				InvertColor:  true,
+				ShowFilename:   true,
+				InvertColor:    true,
+				ProcessOfCount: true,
 			},
 		},
 	}
