@@ -19,7 +19,7 @@ func TestMain(m *testing.M) {
 	os.Exit(ret)
 }
 
-func Test_parseStringNormal(t *testing.T) {
+func Test_StrToContentsNormal(t *testing.T) {
 	t.Parallel()
 	type args struct {
 		line     string
@@ -108,10 +108,9 @@ func Test_parseStringNormal(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
-			got := parseString(tt.args.line, tt.args.tabWidth)
+			got := StrToContents(tt.args.line, tt.args.tabWidth)
 			if !reflect.DeepEqual(got, tt.want) {
 				t.Errorf("parseString() got = %#v, want %#v", got, tt.want)
 			}
@@ -119,7 +118,7 @@ func Test_parseStringNormal(t *testing.T) {
 	}
 }
 
-func Test_parseStringOverlapping(t *testing.T) {
+func Test_StrToContentsOverlapping(t *testing.T) {
 	t.Parallel()
 	type args struct {
 		line     string
@@ -186,10 +185,9 @@ func Test_parseStringOverlapping(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
-			got := parseString(tt.args.line, tt.args.tabWidth)
+			got := StrToContents(tt.args.line, tt.args.tabWidth)
 			if !reflect.DeepEqual(got, tt.want) {
 				t.Errorf("parseString() got = %#v, want %#v", got, tt.want)
 			}
@@ -197,7 +195,7 @@ func Test_parseStringOverlapping(t *testing.T) {
 	}
 }
 
-func Test_parseStringStyle1(t *testing.T) {
+func Test_StrToContentsStyle1(t *testing.T) {
 	t.Parallel()
 	type args struct {
 		line     string
@@ -247,15 +245,6 @@ func Test_parseStringStyle1(t *testing.T) {
 				{width: 1, style: tcell.StyleDefault.Background(tcell.ColorGray), mainc: rune('c'), combc: nil},
 			},
 		},
-		{
-			name: "216 color",
-			args: args{
-				line: "\x1B[38;5;31mc\x1B[m", tabWidth: 8,
-			},
-			want: contents{
-				{width: 1, style: tcell.StyleDefault.Foreground(tcell.NewRGBColor(0, 102, 153)), mainc: 'c', combc: nil},
-			},
-		},
 		{
 			name: "256",
 			args: args{
@@ -344,10 +333,9 @@ func Test_parseStringStyle1(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
-			got := parseString(tt.args.line, tt.args.tabWidth)
+			got := StrToContents(tt.args.line, tt.args.tabWidth)
 			if !reflect.DeepEqual(got, tt.want) {
 				t.Errorf("parseString() got = \n%#v, want \n%#v", got, tt.want)
 			}
@@ -355,48 +343,7 @@ func Test_parseStringStyle1(t *testing.T) {
 	}
 }
 
-func Test_parseStringStyle2(t *testing.T) {
-	type args struct {
-		str      string
-		tabWidth int
-	}
-	tests := []struct {
-		name string
-		args args
-		want contents
-	}{
-		{
-			name: "OverLine",
-			args: args{
-				str: "\x1B[53mol\x1B[m", tabWidth: 8,
-			},
-			want: contents{
-				{width: 1, style: tcell.StyleDefault.Underline(true), mainc: rune('o'), combc: nil},
-				{width: 1, style: tcell.StyleDefault.Underline(true), mainc: rune('l'), combc: nil},
-			},
-		},
-		{
-			name: "UnOverLine",
-			args: args{
-				str: "\x1B[53mo\x1B[m\x1B[55mu\x1B[m\x1B[53ml\x1B[m", tabWidth: 8,
-			},
-			want: contents{
-				{width: 1, style: tcell.StyleDefault.Underline(true), mainc: rune('o'), combc: nil},
-				{width: 1, style: tcell.StyleDefault.Underline(false), mainc: rune('u'), combc: nil},
-				{width: 1, style: tcell.StyleDefault.Underline(true), mainc: rune('l'), combc: nil},
-			},
-		},
-	}
-	for _, tt := range tests {
-		t.Run(tt.name, func(t *testing.T) {
-			if got := parseString(tt.args.str, tt.args.tabWidth); !reflect.DeepEqual(got, tt.want) {
-				t.Errorf("parseString() = %#v, want %#v", got, tt.want)
-			}
-		})
-	}
-}
-
-func Test_parseStringUnStyle(t *testing.T) {
+func Test_StrToContentUnStyle(t *testing.T) {
 	t.Parallel()
 	type args struct {
 		line     string
@@ -481,10 +428,9 @@ func Test_parseStringUnStyle(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
-			got := parseString(tt.args.line, tt.args.tabWidth)
+			got := StrToContents(tt.args.line, tt.args.tabWidth)
 			if !reflect.DeepEqual(got, tt.want) {
 				t.Errorf("parseString() got = \n%#v, want \n%#v", got, tt.want)
 			}
@@ -492,7 +438,7 @@ func Test_parseStringUnStyle(t *testing.T) {
 	}
 }
 
-func Test_parseStringCombining(t *testing.T) {
+func Test_StrToContentsCombining(t *testing.T) {
 	t.Parallel()
 	type args struct {
 		line     string
@@ -542,10 +488,9 @@ func Test_parseStringCombining(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
-			got := parseString(tt.args.line, tt.args.tabWidth)
+			got := StrToContents(tt.args.line, tt.args.tabWidth)
 			if !reflect.DeepEqual(got, tt.want) {
 				t.Errorf("parseString() got = %v, want %v", got, tt.want)
 			}
@@ -553,7 +498,7 @@ func Test_parseStringCombining(t *testing.T) {
 	}
 }
 
-func Test_parseStringHyperlink(t *testing.T) {
+func Test_StrToContentsHyperlink(t *testing.T) {
 	t.Parallel()
 	type args struct {
 		line     string
@@ -586,7 +531,7 @@ func Test_parseStringHyperlink(t *testing.T) {
 		},
 		{
 			name: "testHyperLinkfile",
-			args: args{line: "\x1b]8;;file:///file\afile\x1b]8;;\a", tabWidth: 8},
+			args: args{line: "\x1b]8;;file:///file\afile\x1b]8;;\x1b\\", tabWidth: 8},
 			want: contents{
 				{width: 1, style: tcell.StyleDefault.Url("file:///file"), mainc: rune('f'), combc: nil},
 				{width: 1, style: tcell.StyleDefault.Url("file:///file"), mainc: rune('i'), combc: nil},
@@ -596,10 +541,9 @@ func Test_parseStringHyperlink(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
-			got := parseString(tt.args.line, tt.args.tabWidth)
+			got := StrToContents(tt.args.line, tt.args.tabWidth)
 			if !reflect.DeepEqual(got, tt.want) {
 				t.Errorf("parseString() got = \n%#v, want \n%#v", got, tt.want)
 			}
@@ -652,7 +596,6 @@ func Test_lastContent(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 			if got := tt.args.lc.last(); !reflect.DeepEqual(got, tt.want) {
@@ -662,87 +605,7 @@ func Test_lastContent(t *testing.T) {
 	}
 }
 
-func Test_csToStyle(t *testing.T) {
-	t.Parallel()
-	type args struct {
-		style        tcell.Style
-		csiParameter string
-	}
-	tests := []struct {
-		name string
-		args args
-		want tcell.Style
-	}{
-		{
-			name: "color8bit",
-			args: args{
-				style:        tcell.StyleDefault,
-				csiParameter: "38;5;1",
-			},
-			want: tcell.StyleDefault.Foreground(tcell.ColorMaroon),
-		},
-		{
-			name: "color8bit2",
-			args: args{
-				style:        tcell.StyleDefault,
-				csiParameter: "38;5;21",
-			},
-			want: tcell.StyleDefault.Foreground(tcell.GetColor("#0000ff")),
-		},
-		{
-			name: "attributes",
-			args: args{
-				style:        tcell.StyleDefault,
-				csiParameter: "2;3;4;5;6;7;8;9",
-			},
-			want: tcell.StyleDefault.Dim(true).Italic(true).Underline(true).Blink(true).Reverse(true).StrikeThrough(true),
-		},
-	}
-	for _, tt := range tests {
-		tt := tt
-		t.Run(tt.name, func(t *testing.T) {
-			t.Parallel()
-			if got := csToStyle(tt.args.style, tt.args.csiParameter); !reflect.DeepEqual(got, tt.want) {
-				t.Errorf("csToStyle() = %v, want %v", got, tt.want)
-				gfg, gbg, gattr := got.Decompose()
-				wfg, wbg, wattr := tt.want.Decompose()
-				t.Errorf("csToStyle() = %x,%x,%v, want %x,%x,%v", gfg.Hex(), gbg.Hex(), gattr, wfg.Hex(), wbg.Hex(), wattr)
-			}
-		})
-	}
-}
-
-func Test_strToContents(t *testing.T) {
-	t.Parallel()
-	type args struct {
-		line     string
-		tabWidth int
-	}
-	tests := []struct {
-		name string
-		args args
-		want contents
-	}{
-		{
-			name: "test1",
-			args: args{line: "1", tabWidth: 4},
-			want: contents{
-				{width: 1, style: tcell.StyleDefault, mainc: rune('1'), combc: nil},
-			},
-		},
-	}
-	for _, tt := range tests {
-		tt := tt
-		t.Run(tt.name, func(t *testing.T) {
-			t.Parallel()
-			if got := StrToContents(tt.args.line, tt.args.tabWidth); !reflect.DeepEqual(got, tt.want) {
-				t.Errorf("strToContent() = \n%#v, want \n%#v", got, tt.want)
-			}
-		})
-	}
-}
-
-func Test_contentsToStr(t *testing.T) {
+func Test_ContentsToStr(t *testing.T) {
 	t.Parallel()
 	tests := []struct {
 		name  string
@@ -788,10 +651,9 @@ func Test_contentsToStr(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
-			lc := parseString(tt.str, 8)
+			lc := StrToContents(tt.str, 8)
 			got1, got2 := ContentsToStr(lc)
 			if got1 != tt.want1 {
 				t.Errorf("contentsToStr() = %v, want %v", got1, tt.want1)
@@ -834,7 +696,6 @@ func Test_widthPos_x(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 			if got := tt.pos.x(tt.args.x); got != tt.want {
@@ -881,7 +742,6 @@ func Test_widthPos_n(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 			if got := tt.pos.n(tt.args.w); got != tt.want {
@@ -890,3 +750,164 @@ func Test_widthPos_n(t *testing.T) {
 		})
 	}
 }
+
+func TestRawStrToContents(t *testing.T) {
+	type args struct {
+		str      string
+		tabWidth int
+	}
+	tests := []struct {
+		name string
+		args args
+		want contents
+	}{
+		{
+			name: "red",
+			args: args{
+				str: "\x1B[31mred\x1B[m", tabWidth: 8,
+			},
+			want: contents{
+				{width: 0, style: tcell.StyleDefault, mainc: rune('^'), combc: nil},
+				{width: 0, style: tcell.StyleDefault, mainc: rune('['), combc: nil},
+				{width: 1, style: tcell.StyleDefault, mainc: rune('['), combc: nil},
+				{width: 1, style: tcell.StyleDefault, mainc: rune('3'), combc: nil},
+				{width: 1, style: tcell.StyleDefault, mainc: rune('1'), combc: nil},
+				{width: 1, style: tcell.StyleDefault, mainc: rune('m'), combc: nil},
+				{width: 1, style: tcell.StyleDefault, mainc: rune('r'), combc: nil},
+				{width: 1, style: tcell.StyleDefault, mainc: rune('e'), combc: nil},
+				{width: 1, style: tcell.StyleDefault, mainc: rune('d'), combc: nil},
+				{width: 0, style: tcell.StyleDefault, mainc: rune('^'), combc: nil},
+				{width: 0, style: tcell.StyleDefault, mainc: rune('['), combc: nil},
+				{width: 1, style: tcell.StyleDefault, mainc: rune('['), combc: nil},
+				{width: 1, style: tcell.StyleDefault, mainc: rune('m'), combc: nil},
+			},
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			if got := RawStrToContents(tt.args.str, tt.args.tabWidth); !reflect.DeepEqual(got, tt.want) {
+				str, _ := ContentsToStr(got)
+				str2, _ := ContentsToStr(tt.want)
+				t.Logf("got: %#v %#v", str, str2)
+				t.Errorf("RawStrToContents() = \n%v, want \n%v", got, tt.want)
+			}
+		})
+	}
+}
+
+func Test_parseLine(t *testing.T) {
+	type args struct {
+		str      string
+		tabWidth int
+	}
+	tests := []struct {
+		name  string
+		args  args
+		want  contents
+		want1 tcell.Style
+	}{
+		{
+			name: "testEscapeSequence",
+			args: args{
+				str: "\x1b[31mred\x1b[m",
+			},
+			want: contents{
+				{width: 1, style: tcell.StyleDefault.Foreground(tcell.ColorMaroon), mainc: 'r'},
+				{width: 1, style: tcell.StyleDefault.Foreground(tcell.ColorMaroon), mainc: 'e'},
+				{width: 1, style: tcell.StyleDefault.Foreground(tcell.ColorMaroon), mainc: 'd'},
+			},
+			want1: tcell.StyleDefault,
+		},
+		{
+			name: "testClearLine0",
+			args: args{
+				str: "\x1b[42mt\x1b[0K",
+			},
+			want: contents{
+				{width: 1, style: tcell.StyleDefault.Background(tcell.ColorGreen), mainc: 't'},
+			},
+			want1: tcell.StyleDefault.Background(tcell.ColorGreen),
+		},
+		{
+			name: "testClearLineBlank",
+			args: args{
+				str: "\x1b[42mt\x1b[K",
+			},
+			want: contents{
+				{width: 1, style: tcell.StyleDefault.Background(tcell.ColorGreen), mainc: 't'},
+			},
+			want1: tcell.StyleDefault.Background(tcell.ColorGreen),
+		},
+		{
+			name: "testClearLine1",
+			args: args{
+				str: "\x1b[42mt\x1b[1K", // Not supported
+			},
+			want: contents{
+				{width: 1, style: tcell.StyleDefault.Background(tcell.ColorGreen), mainc: 't'},
+			},
+			want1: tcell.StyleDefault,
+		},
+		{
+			name: "testHyperLinkError",
+			args: args{
+				str: "\x1b]+8;;http://example.com\x1b\\link\x1b]8;;\x1b\\",
+			},
+			want: contents{
+				{width: 1, style: tcell.StyleDefault, mainc: 'l'},
+				{width: 1, style: tcell.StyleDefault, mainc: 'i'},
+				{width: 1, style: tcell.StyleDefault, mainc: 'n'},
+				{width: 1, style: tcell.StyleDefault, mainc: 'k'},
+			},
+		},
+		{
+			name: "testHyperLink",
+			args: args{
+				str: "\x1b]8;;http://example.com\x1b\\link\x1b]8;;\x1b\\",
+			},
+			want: contents{
+				{width: 1, style: tcell.StyleDefault.Url("http://example.com"), mainc: 'l'},
+				{width: 1, style: tcell.StyleDefault.Url("http://example.com"), mainc: 'i'},
+				{width: 1, style: tcell.StyleDefault.Url("http://example.com"), mainc: 'n'},
+				{width: 1, style: tcell.StyleDefault.Url("http://example.com"), mainc: 'k'},
+			},
+			want1: tcell.StyleDefault,
+		},
+		{
+			name: "testHyperLinkID",
+			args: args{
+				str: "\x1b]8;1;http://example.com\x1b\\link\x1b]8;;\x1b\\",
+			},
+			want: contents{
+				{width: 1, style: tcell.StyleDefault.Url("http://example.com").UrlId("1"), mainc: 'l'},
+				{width: 1, style: tcell.StyleDefault.Url("http://example.com").UrlId("1"), mainc: 'i'},
+				{width: 1, style: tcell.StyleDefault.Url("http://example.com").UrlId("1"), mainc: 'n'},
+				{width: 1, style: tcell.StyleDefault.Url("http://example.com").UrlId("1"), mainc: 'k'},
+			},
+		},
+		{
+			name: "testHyperLinkFile",
+			args: args{
+				str: "\x1b]8;;file:///file\afile\x1b]8;;\a",
+			},
+			want: contents{
+				{width: 1, style: tcell.StyleDefault.Url("file:///file"), mainc: 'f'},
+				{width: 1, style: tcell.StyleDefault.Url("file:///file"), mainc: 'i'},
+				{width: 1, style: tcell.StyleDefault.Url("file:///file"), mainc: 'l'},
+				{width: 1, style: tcell.StyleDefault.Url("file:///file"), mainc: 'e'},
+			},
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			conv := newESConverter()
+			got, got1 := parseLine(conv, tt.args.str, tt.args.tabWidth)
+			if !reflect.DeepEqual(got, tt.want) {
+				t.Errorf("parseLine() got = \n%#v, want \n%#v", got, tt.want)
+			}
+			if !reflect.DeepEqual(got1, tt.want1) {
+				t.Errorf("parseLine() got1 = %#v, want %#v", got1, tt.want1)
+			}
+		})
+	}
+}
