@@ -22,7 +22,7 @@ func (root *Root) getDocument(docNum int) *Document {
 	return root.DocList[docNum]
 }
 
-// hasDocChanged() returns if doc has changed.
+// hasDocChanged checks if any document in the list has changed.
 func (root *Root) hasDocChanged() bool {
 	root.mu.RLock()
 	defer root.mu.RUnlock()
@@ -115,8 +115,14 @@ func (root *Root) nextDoc(ctx context.Context) {
 func (root *Root) previousDoc(ctx context.Context) {
 	fromNum := root.CurrentDoc
 	fromDoc := root.getDocument(fromNum)
+	if fromDoc == nil {
+		return
+	}
 	toNum := root.CurrentDoc - 1
 	toDoc := root.getDocument(toNum)
+	if toDoc == nil {
+		return
+	}
 
 	root.setDocumentNum(ctx, toNum)
 	root.input.Event = normal()
@@ -135,7 +141,7 @@ func (root *Root) linkLineNum(fromDoc, toDoc *Document) {
 	}
 	if n, ok := fromDoc.lineNumMap.LoadForward(fromDoc.topLN + fromDoc.firstLine()); ok {
 		root.debugMessage("Move parent line number")
-		toDoc.moveLine(n)
+		toDoc.moveLine(n - toDoc.firstLine())
 	}
 }
 
