@@ -5,10 +5,12 @@ import (
 	"fmt"
 	"log"
 	"strings"
+	"time"
 
 	"github.com/gdamore/tcell/v2"
 )
 
+// defaultStyle is used when the style is not specified.
 var defaultStyle = tcell.StyleDefault
 
 // draw is the main routine that draws the screen.
@@ -50,6 +52,8 @@ func (root *Root) draw(ctx context.Context) {
 func (root *Root) drawBody(lX int, lN int) (int, int) {
 	m := root.Doc
 
+	markStyleWidth := min(root.scr.vWidth, root.Doc.general.MarkStyleWidth)
+
 	wrapNum := m.numOfWrap(lX, lN)
 	for y := m.headerHeight; y < root.scr.vHeight-statusLine; y++ {
 		line, ok := root.scr.lines[lN]
@@ -59,7 +63,7 @@ func (root *Root) drawBody(lX int, lN int) (int, int) {
 		root.scr.numbers[y] = newLineNumber(lN, wrapNum)
 		root.drawLineNumber(lN, y, line.valid)
 
-		nextLX, nextLN := root.drawLine(y, lX, lN, line.lc)
+		nextLX, nextLN := root.drawLine(y, lX, lN, line)
 		if line.valid {
 			root.coordinatesStyle(lN, y)
 		}
@@ -69,6 +73,7 @@ func (root *Root) drawBody(lX int, lN int) (int, int) {
 				root.hideOtherSection(y, line)
 			}
 		}
+		root.applyMarkStyle(lN, y, markStyleWidth)
 
 		wrapNum++
 		if nextLX == 0 {
@@ -90,16 +95,16 @@ func (root *Root) drawHeader() {
 	lX := 0
 	lN := root.scr.headerLN
 	for y := 0; y < m.headerHeight && lN < root.scr.headerEnd; y++ {
-		line, ok := root.scr.lines[lN]
+		lineC, ok := root.scr.lines[lN]
 		if !ok {
 			panic(fmt.Sprintf("line is not found %d", lN))
 		}
 		root.scr.numbers[y] = newLineNumber(lN, wrapNum)
 		root.blankLineNumber(y)
 
-		lX, lN = root.drawLine(y, lX, lN, line.lc)
+		lX, lN = root.drawLine(y, lX, lN, lineC)
 		// header style.
-		root.yStyle(y, root.StyleHeader)
+		root.applyStyleToLine(y, root.StyleHeader)
 
 		wrapNum++
 		if lX == 0 {
@@ -117,22 +122,22 @@ func (root *Root) drawSectionHeader() {
 	lX := 0
 	lN := root.scr.sectionHeaderLN
 	for y := m.headerHeight; y < m.headerHeight+m.sectionHeaderHeight && lN < root.scr.sectionHeaderEnd; y++ {
-		line, ok := root.scr.lines[lN]
+		lineC, ok := root.scr.lines[lN]
 		if !ok {
 			panic(fmt.Sprintf("line is not found %d", lN))
 		}
 		root.scr.numbers[y] = newLineNumber(lN, wrapNum)
-		root.drawLineNumber(lN, y, line.valid)
+		root.drawLineNumber(lN, y, lineC.valid)
 
-		nextLX, nextLN := root.drawLine(y, lX, lN, line.lc)
+		nextLX, nextLN := root.drawLine(y, lX, lN, lineC)
 		// section header style.
-		root.yStyle(y, root.StyleSectionLine)
+		root.applyStyleToLine(y, root.StyleSectionLine)
 		// markstyle is displayed above the section header.
 		markStyleWidth := min(root.scr.vWidth, m.general.MarkStyleWidth)
-		root.markStyle(lN, y, markStyleWidth)
+		root.applyMarkStyle(lN, y, markStyleWidth)
 		// Underline search lines when they overlap in section headers.
 		if lN == m.lastSearchLN {
-			root.yStyle(y, OVStyle{Underline: true})
+			root.applyStyleToLine(y, OVStyle{Underline: true})
 		}
 
 		wrapNum++
@@ -146,60 +151,66 @@ func (root *Root) drawSectionHeader() {
 }
 
 // drawWrapLine wraps and draws the contents and returns the next drawing position.
-func (root *Root) drawLine(y int, lX int, lN int, lc contents) (int, int) {
+func (root *Root) drawLine(y int, lX int, lN int, lineC LineC) (int, int) {
 	if root.Doc.WrapMode {
-		return root.drawWrapLine(y, lX, lN, lc)
+		return root.drawWrapLine(y, lX, lN, lineC)
 	}
 
-	return root.drawNoWrapLine(y, root.Doc.x, lN, lc)
+	return root.drawNoWrapLine(y, root.Doc.x, lN, lineC)
 }
 
 // drawWrapLine wraps and draws the contents and returns the next drawing position.
-func (root *Root) drawWrapLine(y int, lX int, lN int, lc contents) (int, int) {
+func (root *Root) drawWrapLine(y int, lX int, lN int, lineC LineC) (int, int) {
 	if lX < 0 {
 		log.Printf("Illegal lX:%d", lX)
 		return 0, 0
 	}
 
-	for x := 0; ; x++ {
-		if lX+x >= len(lc) {
+	screen := root.Screen
+	for n := 0; ; n++ {
+		x := root.scr.startX + n
+		if lX+n >= len(lineC.lc) {
 			// EOL
-			root.clearEOL(root.scr.startX+x, y)
+			root.clearEOL(x, y, lineC.eolStyle)
 			lX = 0
 			lN++
 			break
 		}
-		content := lc[lX+x]
-		if x+root.scr.startX+content.width > root.scr.vWidth {
+		c := lineC.lc[lX+n]
+		if x+c.width > root.scr.vWidth {
 			// Right edge.
-			root.clearEOL(root.scr.startX+x, y)
-			lX += x
+			root.clearEOL(x, y, defaultStyle)
+			lX += n
 			break
 		}
-		root.Screen.SetContent(root.scr.startX+x, y, content.mainc, content.combc, content.style)
+		screen.SetContent(x, y, c.mainc, c.combc, c.style)
 	}
 
 	return lX, lN
 }
 
 // drawNoWrapLine draws contents without wrapping and returns the next drawing position.
-func (root *Root) drawNoWrapLine(y int, startX int, lN int, lc contents) (int, int) {
-	startX = max(startX, root.minStartX)
-	for x := 0; root.scr.startX+x < root.scr.vWidth; x++ {
-		if startX+x >= len(lc) {
+func (root *Root) drawNoWrapLine(y int, lX int, lN int, lineC LineC) (int, int) {
+	lX = max(lX, root.minStartX)
+	screen := root.Screen
+	for n := 0; root.scr.startX+n < root.scr.vWidth; n++ {
+		x := root.scr.startX + n
+		if lX+n >= len(lineC.lc) {
 			// EOL
-			root.clearEOL(root.scr.startX+x, y)
+			root.clearEOL(x, y, lineC.eolStyle)
 			break
 		}
-		content := DefaultContent
-		if startX+x >= 0 {
-			content = lc[startX+x]
+		if lX+n < 0 {
+			c := DefaultContent
+			screen.SetContent(x, y, c.mainc, c.combc, c.style)
+			continue
 		}
-		root.Screen.SetContent(root.scr.startX+x, y, content.mainc, content.combc, content.style)
+		c := lineC.lc[lX+n]
+		screen.SetContent(x, y, c.mainc, c.combc, c.style)
 	}
 	lN++
 
-	return startX, lN
+	return lX, lN
 }
 
 // blankLineNumber should be blank for the line number.
@@ -255,57 +266,62 @@ func (root *Root) setContentString(vx int, vy int, lc contents) {
 }
 
 // clearEOL clears from the specified position to the right end.
-func (root *Root) clearEOL(x int, y int) {
+func (root *Root) clearEOL(x int, y int, style tcell.Style) {
 	for ; x < root.scr.vWidth; x++ {
-		root.Screen.SetContent(x, y, ' ', nil, defaultStyle)
+		root.Screen.SetContent(x, y, ' ', nil, style)
 	}
 }
 
 // clearY clear the specified line.
 func (root *Root) clearY(y int) {
-	root.clearEOL(0, y)
+	root.clearEOL(0, y, defaultStyle)
 }
 
 // coordinatesStyle applies the style of the coordinates.
 func (root *Root) coordinatesStyle(lN int, y int) {
-	root.alternateRowsStyle(lN, y)
-	markStyleWidth := min(root.scr.vWidth, root.Doc.general.MarkStyleWidth)
-	root.markStyle(lN, y, markStyleWidth)
+	root.applyStyleToAlternate(lN, y)
 	if root.Doc.jumpTargetHeight != 0 && root.Doc.headerHeight+root.Doc.jumpTargetHeight == y {
-		root.yStyle(y, root.StyleJumpTargetLine)
+		root.applyStyleToLine(y, root.StyleJumpTargetLine)
 	}
 }
 
-// alternateRowsStyle applies from beginning to end of line.
-func (root *Root) alternateRowsStyle(lN int, y int) {
+// applyStyleToAlternate applies from beginning to end of line.
+func (root *Root) applyStyleToAlternate(lN int, y int) {
 	if !root.Doc.AlternateRows {
 		return
 	}
 	if (lN)%2 == 0 {
 		return
 	}
-	root.yStyle(y, root.StyleAlternate)
+	root.applyStyleToLine(y, root.StyleAlternate)
 }
 
-// yStyle applies the style from the left edge to the right edge of the physical line.
+// applyStyleToLine applies the style from the left edge to the right edge of the physical line.
 // Apply styles to the screen.
-func (root *Root) yStyle(y int, s OVStyle) {
-	root.yRangeStyle(y, s, 0, root.scr.vWidth)
+func (root *Root) applyStyleToLine(y int, s OVStyle) {
+	root.applyStyleToRange(y, s, 0, root.scr.vWidth)
 }
 
-// markStyle applies the style from the left edge to the specified width.
-func (root *Root) markStyle(lN int, y int, width int) {
+// applyMarkStyle applies the style from the left edge to the specified width.
+func (root *Root) applyMarkStyle(lN int, y int, width int) {
 	m := root.Doc
 	if !contains(m.marked, lN) {
 		return
 	}
-	root.yRangeStyle(y, root.StyleMarkLine, 0, width)
+	root.applyStyleToRange(y, root.StyleMarkLine, 0, width)
 }
 
-func (root *Root) yRangeStyle(y int, s OVStyle, start int, end int) {
+// applyStyleToRange applies the style from the start to the end of the physical line.
+func (root *Root) applyStyleToRange(y int, s OVStyle, start int, end int) {
 	for x := start; x < end; x++ {
-		r, c, ts, _ := root.GetContent(x, y)
-		root.Screen.SetContent(x, y, r, c, applyStyle(ts, s))
+		mainc, combc, style, width := root.GetContent(x, y)
+		newStyle := applyStyle(style, s)
+		if style != newStyle {
+			root.Screen.SetContent(x, y, mainc, combc, newStyle)
+		}
+		if width == 2 {
+			x++
+		}
 	}
 }
 
@@ -320,7 +336,7 @@ func (root *Root) sectionLineHighlight(y int, line LineC) {
 	if line.sectionNm <= 0 || line.sectionNm > root.Doc.SectionHeaderNum {
 		return
 	}
-	root.yStyle(y, root.StyleSectionLine)
+	root.applyStyleToLine(y, root.StyleSectionLine)
 }
 
 // hideOtherSection hides other sections.
@@ -328,7 +344,6 @@ func (root *Root) hideOtherSection(y int, line LineC) {
 	if line.section <= 1 { // 1 is the first section.
 		return
 	}
-
 	root.clearY(y)
 }
 
@@ -344,25 +359,25 @@ func (root *Root) drawSelect(x1, y1, x2, y2 int, sel bool) {
 		if x2 < x1 {
 			x1, x2 = x2, x1
 		}
-		root.reverseLine(y1, x1, x2+1, sel)
+		root.reverseRange(y1, x1, x2+1, sel)
 		return
 	}
 	if root.scr.mouseRectangle {
 		for y := y1; y <= y2; y++ {
-			root.reverseLine(y, x1, x2+1, sel)
+			root.reverseRange(y, x1, x2+1, sel)
 		}
 		return
 	}
 
-	root.reverseLine(y1, x1, root.scr.vWidth, sel)
+	root.reverseRange(y1, x1, root.scr.vWidth, sel)
 	for y := y1 + 1; y < y2; y++ {
-		root.reverseLine(y, 0, root.scr.vWidth, sel)
+		root.reverseRange(y, 0, root.scr.vWidth, sel)
 	}
-	root.reverseLine(y2, 0, x2+1, sel)
+	root.reverseRange(y2, 0, x2+1, sel)
 }
 
-// reverseLine reverses one line.
-func (root *Root) reverseLine(y int, start int, end int, sel bool) {
+// reverseRange reverses the specified range.
+func (root *Root) reverseRange(y int, start int, end int, sel bool) {
 	if start >= end {
 		return
 	}
@@ -375,3 +390,29 @@ func (root *Root) reverseLine(y int, start int, end int, sel bool) {
 		}
 	}
 }
+
+// notifyEOFReached notifies that EOF has been reached.
+func (root *Root) notifyEOFReached(m *Document) {
+	root.setMessagef("EOF reached %s", m.FileName)
+	root.notify(root.Config.NotifyEOF)
+}
+
+// notify notifies by beeping and flashing the screen the specified number of times.
+func (root *Root) notify(count int) {
+	for i := 0; i < count; i++ {
+		root.Screen.Beep()
+		root.flash()
+	}
+}
+
+// flash flashes the screen.
+func (root *Root) flash() {
+	root.Screen.Fill(' ', tcell.StyleDefault.Background(tcell.ColorWhite))
+	root.Screen.Sync()
+	time.Sleep(50 * time.Millisecond)
+	root.Screen.Fill(' ', tcell.StyleDefault.Background(tcell.ColorBlack))
+	root.Screen.Sync()
+	time.Sleep(50 * time.Millisecond)
+	root.draw(context.Background())
+	time.Sleep(100 * time.Millisecond)
+}
