@@ -60,6 +60,8 @@ func (root *Root) event(ctx context.Context, ev tcell.Event) bool {
 		root.pasteFromClipboard(ctx)
 	case *eventViewMode:
 		root.setViewMode(ctx, ev.value)
+	case *eventConverter:
+		root.setConverter(ctx, ev.value)
 	case *eventInputSearch:
 		root.firstSearch(ctx, ev.searchType)
 	case *eventSearch:
@@ -69,7 +71,7 @@ func (root *Root) event(ctx context.Context, ev tcell.Event) bool {
 	case *eventNextBackSearch:
 		root.backSearch(ctx, ev.str, -1)
 	case *eventSearchMove:
-		root.searchGo(ctx, ev.value)
+		root.searchGo(ctx, ev.ln, ev.searcher)
 	case *eventGoto:
 		root.goLine(ev.value)
 	case *eventHeader:
@@ -96,6 +98,8 @@ func (root *Root) event(ctx context.Context, ev tcell.Event) bool {
 		root.saveBuffer(ev.value)
 	case *eventSectionNum:
 		root.setSectionNum(ev.value)
+	case *eventReachEOF:
+		root.notifyEOFReached(ev.m)
 
 	// tcell events
 	case *tcell.EventResize:
@@ -139,14 +143,20 @@ func (root *Root) everyUpdate(ctx context.Context) {
 	// This process is executed when temporary read is switched to normal read.
 	if n := atomic.SwapInt32(&root.Doc.tmpLN, 0); n > 0 {
 		tmpN := int(n) - root.Doc.topLN
-		root.Doc.topLN = root.Doc.BufEndNum() - tmpN
+		if tmpN > 0 {
+			root.Doc.topLN = root.Doc.BufEndNum() - tmpN
+		}
 	}
 
 	root.Doc.width = root.scr.vWidth - root.scr.startX
 	root.Doc.height = root.Doc.statusPos - root.Doc.headerHeight
-
-	if root.General.FollowAll || root.Doc.FollowMode || root.Doc.FollowSection {
+	switch {
+	case root.General.FollowAll:
+		root.followAll(ctx)
+	case root.Doc.FollowMode:
 		root.follow(ctx)
+	case root.Doc.FollowSection:
+		root.followSection(ctx)
 	}
 
 	if !root.skipDraw && root.Doc.height > 0 {
@@ -251,11 +261,12 @@ type eventDocument struct {
 }
 
 // SetDocument fires the eventDocument event.
-func (root *Root) SetDocument(docNum int) {
-	if docNum < 0 || docNum < root.DocumentLen() {
-		return
+func (root *Root) SetDocument(docNum int) error {
+	if docNum < 0 || docNum >= root.DocumentLen() {
+		return ErrInvalidDocumentNum
 	}
 	root.sendDocument(docNum)
+	return nil
 }
 
 func (root *Root) sendDocument(docNum int) {
@@ -352,3 +363,36 @@ func (root *Root) postEvent(ev tcell.Event) {
 		root.releaseEventBuffer()
 	}
 }
+
+// eventReachEOF represents an EOF event.
+type eventReachEOF struct {
+	m *Document
+	tcell.EventTime
+}
+
+// sendReachEOF fires the eventReachEOF event.
+func (root *Root) sendReachEOF(m *Document) {
+	ev := &eventReachEOF{}
+	ev.m = m
+	ev.SetEventNow()
+	root.postEvent(ev)
+}
+
+// monitorEOF monitors the EOF of the document.
+func (root *Root) monitorEOF() {
+	if root.Config.NotifyEOF == 0 {
+		return
+	}
+	log.Println("monitorEOF")
+	for _, m := range root.DocList {
+		go func() {
+			if !m.BufEOF() {
+				m.cond.L.Lock()
+				m.cond.Wait()
+				m.cond.L.Unlock()
+			}
+			root.sendReachEOF(m)
+			log.Println("EOF reached", m.FileName)
+		}()
+	}
+}
