@@ -82,6 +82,10 @@ const (
 	actionJumpTarget     = "jump_target"
 	actionSaveBuffer     = "save_buffer"
 	actionHideOther      = "hide_other"
+	actionConvertType    = "convert_type"
+	actionAlignFormat    = "align_format"
+	actionRawFormat      = "raw_format"
+	actionShrinkColumn   = "shrink_column"
 
 	inputCaseSensitive      = "input_casesensitive"
 	inputSmartCaseSensitive = "input_smart_casesensitive"
@@ -135,8 +139,8 @@ func (root *Root) handlers() map[string]func(context.Context) {
 		actionNextSection:    root.nextSection,
 		actionPrevSection:    root.prevSection,
 		actionLastSection:    root.lastSection,
-		actionMoveMark:       root.markNext,
-		actionMovePrevMark:   root.markPrev,
+		actionMoveMark:       root.nextMark,
+		actionMovePrevMark:   root.prevMark,
 		actionViewMode:       root.setViewInputMode,
 		actionWrap:           root.toggleWrapMode,
 		actionColumnMode:     root.toggleColumnMode,
@@ -166,6 +170,10 @@ func (root *Root) handlers() map[string]func(context.Context) {
 		actionJumpTarget:     root.setJumpTargetMode,
 		actionSaveBuffer:     root.setSaveBuffer,
 		actionHideOther:      root.toggleHideOtherSection,
+		actionConvertType:    root.setConvertType,
+		actionAlignFormat:    root.alignFormat,
+		actionRawFormat:      root.rawFormat,
+		actionShrinkColumn:   root.toggleColumnShrink,
 
 		inputCaseSensitive:      root.inputCaseSensitive,
 		inputSmartCaseSensitive: root.inputSmartCaseSensitive,
@@ -254,6 +262,10 @@ func defaultKeyBinds() KeyBind {
 		actionJumpTarget:     {"j"},
 		actionSaveBuffer:     {"S"},
 		actionHideOther:      {"alt+-"},
+		actionConvertType:    {"alt+t"},
+		actionAlignFormat:    {"alt+F"},
+		actionRawFormat:      {"alt+R"},
+		actionShrinkColumn:   {"s"},
 
 		inputCaseSensitive:      {"alt+c"},
 		inputSmartCaseSensitive: {"alt+s"},
@@ -328,9 +340,12 @@ func (k KeyBind) String() string {
 	k.writeKeyBind(&b, actionColumnMode, "column mode toggle")
 	k.writeKeyBind(&b, actionColumnWidth, "column width toggle")
 	k.writeKeyBind(&b, actionRainbow, "column rainbow toggle")
+	k.writeKeyBind(&b, actionShrinkColumn, "shrink column toggle")
 	k.writeKeyBind(&b, actionAlternate, "alternate rows of style toggle")
 	k.writeKeyBind(&b, actionLineNumMode, "line number toggle")
 	k.writeKeyBind(&b, actionPlain, "original decoration toggle(plain)")
+	k.writeKeyBind(&b, actionAlignFormat, "align columns")
+	k.writeKeyBind(&b, actionRawFormat, "raw output")
 
 	writeHeader(&b, "Change Display with Input")
 	k.writeKeyBind(&b, actionViewMode, "view mode selection")
@@ -340,6 +355,7 @@ func (k KeyBind) String() string {
 	k.writeKeyBind(&b, actionTabWidth, "TAB width")
 	k.writeKeyBind(&b, actionMultiColor, "multi color highlight")
 	k.writeKeyBind(&b, actionJumpTarget, "jump target(`.n` or `n%` or `section` allowed)")
+	k.writeKeyBind(&b, actionConvertType, "convert type selection")
 
 	writeHeader(&b, "Section")
 	k.writeKeyBind(&b, actionSection, "section delimiter regular expression")
@@ -349,7 +365,7 @@ func (k KeyBind) String() string {
 	k.writeKeyBind(&b, actionLastSection, "last section")
 	k.writeKeyBind(&b, actionFollowSection, "follow section mode toggle")
 	k.writeKeyBind(&b, actionSectionNum, "number of section header lines")
-	k.writeKeyBind(&b, actionHideOther, "toggle hide other section")
+	k.writeKeyBind(&b, actionHideOther, `hide "other" section toggle`)
 
 	writeHeader(&b, "Close and reload")
 	k.writeKeyBind(&b, actionCloseFile, "close file")
