@@ -126,6 +126,8 @@ func newLineNumber(number, wrap int) LineNumber {
 // general structure contains the general of the display.
 // general contains values that determine the behavior of each document.
 type general struct {
+	// Converter is the converter name.
+	Converter string
 	// Caption is an additional caption to display after the file name.
 	Caption string
 	// ColumnDelimiterReg is a compiled regular expression of ColumnDelimiter.
@@ -272,53 +274,17 @@ type Config struct {
 	RegexpSearch bool
 	// Incsearch is incremental search if true.
 	Incsearch bool
+	// NotifyEOF specifies the number of times to notify EOF.
+	NotifyEOF int
 
+	// ShrinkChar is the character to display when the column is shrunk.
+	ShrinkChar string
 	// DisableColumnCycle is disable column cycle.
 	DisableColumnCycle bool
 	// Debug represents whether to enable the debug output.
 	Debug bool
 }
 
-// OVStyle represents a style in addition to the original style.
-type OVStyle struct {
-	// Background is a color name string.
-	Background string
-	// Foreground is a color name string.
-	Foreground string
-	// If true, add blink.
-	Blink bool
-	// If true, add bold.
-	Bold bool
-	// If true, add dim.
-	Dim bool
-	// If true, add italic.
-	Italic bool
-	// If true, add reverse.
-	Reverse bool
-	// If true, add underline.
-	Underline bool
-	// If true, add strike through.
-	StrikeThrough bool
-	// If true, add overline (not yet supported).
-	OverLine bool
-	// If true, sub blink.
-	UnBlink bool
-	// If true, sub bold.
-	UnBold bool
-	// If true, sub dim.
-	UnDim bool
-	// If true, sub italic.
-	UnItalic bool
-	// If true, sub reverse.
-	UnReverse bool
-	// If true, sub underline.
-	UnUnderline bool
-	// If true, sub strike through.
-	UnStrikeThrough bool
-	// if true, sub underline (not yet supported).
-	UnOverLine bool
-}
-
 var (
 	// MemoryLimit is a number that limits the chunks to load into memory.
 	MemoryLimit int
@@ -356,6 +322,17 @@ const QuitSmallCountDown = 10
 // when the debug flag is enabled.
 const MaxWriteLog int = 10
 
+// The name of the converter that can be specified.
+const (
+	convEscaped string = "es"    // convEscaped processes escape sequence(default).
+	convRaw     string = "raw"   // convRaw is displayed without processing escape sequences as they are.
+	convAlign   string = "align" // convAlign is aligned in each column.
+)
+
+const (
+	nameGeneral string = "general"
+)
+
 var (
 	// ErrOutOfRange indicates that value is out of range.
 	ErrOutOfRange = errors.New("out of range")
@@ -369,6 +346,8 @@ var (
 	ErrIsDirectory = errors.New("is a directory")
 	// ErrNotFound indicates not found.
 	ErrNotFound = errors.New("not found")
+	// ErrNotTerminal indicates that it is not a terminal.
+	ErrNotTerminal = errors.New("not a terminal")
 	// ErrCancel indicates cancel.
 	ErrCancel = errors.New("cancel")
 	// ErrInvalidNumber indicates an invalid number.
@@ -405,6 +384,16 @@ var (
 	ErrAlreadyLoaded = errors.New("chunk already loaded")
 	// ErrEvictedMemory indicates that it has been evicted from memory.
 	ErrEvictedMemory = errors.New("evicted memory")
+	// ErrNotAlignMode indicates that it is not an align mode.
+	ErrNotAlignMode = errors.New("not an align mode")
+	// ErrNoColumnSelected indicates that no column is selected.
+	ErrNoColumnSelected = errors.New("no column selected")
+	// ErrInvalidSGR indicates that the SGR is invalid.
+	ErrInvalidSGR = errors.New("invalid SGR")
+	// ErrNotSuuport indicates that it is not supported.
+	ErrNotSuuport = errors.New("not support")
+	// ErrInvalidDocumentNum indicates that the document number is invalid.
+	ErrInvalidDocumentNum = errors.New("invalid document number")
 )
 
 // This is a function of tcell.NewScreen but can be replaced with mock.
@@ -465,7 +454,11 @@ func NewRoot(r io.Reader) (*Root, error) {
 func Open(fileNames ...string) (*Root, error) {
 	switch len(fileNames) {
 	case 0:
-		return openSTDIN()
+		root, err := openSTDIN()
+		if err != nil {
+			return nil, ErrMissingFile
+		}
+		return root, nil
 	case 1:
 		return openFile(fileNames[0])
 	default:
@@ -495,28 +488,37 @@ func openFile(fileName string) (*Root, error) {
 // openFiles opens multiple files and creates root.
 // It will continue even if there are files that fail to open.
 func openFiles(fileNames []string) (*Root, error) {
-	errors := make([]string, 0)
+	var openErrs []error
 	docList := make([]*Document, 0)
 	for _, fileName := range fileNames {
 		m, err := OpenDocument(fileName)
 		if err != nil {
-			errors = append(errors, fmt.Sprintf("open error: %s", err))
+			openErrs = append(openErrs, err)
 			continue
 		}
 		docList = append(docList, m)
 	}
 
-	if len(docList) == 0 {
-		return nil, fmt.Errorf("%w: %s", ErrMissingFile, fileNames[0])
+	if len(openErrs) > 1 {
+		openErrs = append([]error{ErrMissingFile}, openErrs...)
 	}
+	errs := errors.Join(openErrs...)
+	// If none of the documents are present, the program exits with an error.
+	if len(docList) == 0 {
+		return nil, errs
+	}
+
 	root, err := NewOviewer(docList...)
 	if err != nil {
 		return nil, err
 	}
-
-	for _, e := range errors {
-		log.Println(e)
+	// Errors that could not be OpenDocument are output to the log.
+	if errs, ok := errs.(interface{ Unwrap() []error }); ok {
+		for _, err := range errs.Unwrap() {
+			log.Println(err)
+		}
 	}
+
 	return root, err
 }
 
@@ -587,7 +589,7 @@ func (root *Root) sendRequest(m *Document, request request) {
 	case m.ctlCh <- controlSpecifier{request: request}:
 		root.debugMessage(fmt.Sprintf("notify send %v", request))
 	default:
-		root.debugMessage(fmt.Sprintf("notify send fail %s", request))
+		root.debugMessage(fmt.Sprintf("notify send fail %v", request))
 	}
 }
 
@@ -641,6 +643,8 @@ func (root *Root) Run() error {
 	sigSuspend := registerSIGTSTP()
 	quitChan := make(chan struct{})
 
+	root.monitorEOF()
+
 	go func() {
 		// Undo screen when goroutine panic.
 		defer func() {
@@ -679,6 +683,11 @@ func (root *Root) prepareRun(ctx context.Context) error {
 		root.Screen.EnableMouse(MouseFlags)
 	}
 
+	if root.Config.ShrinkChar != "" {
+		Shrink = []rune(root.Config.ShrinkChar)[0]
+	}
+	SetShrinkContent(Shrink)
+
 	root.setCaption()
 
 	root.setViewModeConfig()
@@ -712,7 +721,7 @@ func (root *Root) setCaption() {
 // setViewModeConfig sets view mode config.
 func (root *Root) setViewModeConfig() {
 	list := make([]string, 0, len(root.Config.Mode)+1)
-	list = append(list, "general")
+	list = append(list, nameGeneral)
 	for name := range root.Config.Mode {
 		list = append(list, name)
 	}
@@ -731,6 +740,9 @@ func (root *Root) prepareAllDocuments() {
 		if doc.ColumnWidth {
 			doc.ColumnMode = true
 		}
+		if doc.general.Converter != "" {
+			doc.conv = doc.converterType(doc.general.Converter)
+		}
 		w := ""
 		if doc.general.WatchInterval > 0 {
 			doc.watchMode()
@@ -794,84 +806,6 @@ func (root *Root) debugMessage(msg string) {
 	log.Printf("%s:%s", root.Doc.FileName, msg)
 }
 
-// ToTcellStyle convert from ovStyle to tcell style.
-func ToTcellStyle(s OVStyle) tcell.Style {
-	style := tcell.StyleDefault
-	style = style.Background(tcell.GetColor(s.Background))
-	style = style.Foreground(tcell.GetColor(s.Foreground))
-	style = style.Blink(s.Blink)
-	style = style.Bold(s.Bold)
-	style = style.Dim(s.Dim)
-	style = style.Italic(s.Italic)
-	style = style.Reverse(s.Reverse)
-	style = style.Underline(s.Underline)
-	style = style.StrikeThrough(s.StrikeThrough)
-
-	return style
-}
-
-func applyStyle(style tcell.Style, s OVStyle) tcell.Style {
-	if s.Background != "" {
-		style = style.Background(tcell.GetColor(s.Background))
-	}
-	if s.Foreground != "" {
-		style = style.Foreground(tcell.GetColor(s.Foreground))
-	}
-	if s.Blink {
-		style = style.Blink(true)
-	}
-	if s.Bold {
-		style = style.Bold(true)
-	}
-	if s.Dim {
-		style = style.Dim(true)
-	}
-	if s.Italic {
-		style = style.Italic(true)
-	}
-	if s.Reverse {
-		style = style.Reverse(true)
-	}
-	if s.Underline {
-		style = style.Underline(true)
-	}
-	if s.StrikeThrough {
-		style = style.StrikeThrough(true)
-	}
-	if s.UnBlink {
-		style = style.Blink(false)
-	}
-	if s.UnBold {
-		style = style.Bold(false)
-	}
-	if s.UnDim {
-		style = style.Dim(false)
-	}
-	if s.UnItalic {
-		style = style.Italic(false)
-	}
-	if s.UnReverse {
-		style = style.Reverse(false)
-	}
-	if s.UnUnderline {
-		style = style.Underline(false)
-	}
-	if s.UnStrikeThrough {
-		style = style.StrikeThrough(false)
-	}
-	if s.OverLine {
-		// tcell does not support overline.
-		// style = style.OverLine(true)
-		style = style.Underline(true)
-	}
-	if s.UnOverLine {
-		// tcell does not support unOverline.
-		// style = style.UnOverLine(false)
-		style = style.Underline(false)
-	}
-	return style
-}
-
 // mergeGeneral overwrites a general structure with a struct.
 func mergeGeneral(src general, dst general) general {
 	if dst.TabWidth != 0 {
@@ -946,6 +880,9 @@ func mergeGeneral(src general, dst general) general {
 	if dst.HideOtherSection {
 		src.HideOtherSection = dst.HideOtherSection
 	}
+	if dst.Converter != "" {
+		src.Converter = dst.Converter
+	}
 	return src
 }
 
@@ -958,7 +895,7 @@ func (root *Root) docSmall() bool {
 	}
 	height := 0
 	for y := 0; y < m.BufEndNum(); y++ {
-		lc, err := m.contents(y, root.Doc.TabWidth)
+		lc, err := m.contents(y)
 		if err != nil {
 			log.Printf("docSmall %d: %s", y, err)
 			continue
