@@ -43,8 +43,7 @@ func rootFileReadHelper(t *testing.T, fileNames ...string) *Root {
 	}
 	root.mu.RLock()
 	for _, doc := range root.DocList {
-		for !doc.BufEOF() {
-		}
+		doc.WaitEOF()
 	}
 	root.mu.RUnlock()
 	return root
@@ -264,7 +263,6 @@ func Test_applyStyle(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 			if got := applyStyle(tt.args.style, tt.args.s); !reflect.DeepEqual(got, tt.want) {
