@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"path/filepath"
 	"reflect"
+	"regexp"
 	"testing"
 	"time"
 
@@ -590,7 +591,7 @@ func TestRoot_styleContent(t *testing.T) {
 			m.setColumnWidths()
 			root.scr.lines = make(map[int]LineC)
 			root.prepareDraw(context.Background())
-			line := m.getLineC(tt.args.lineNum, m.TabWidth)
+			line := m.getLineC(tt.args.lineNum)
 			if line.lc == nil {
 				t.Fatal("line is nil")
 			}
@@ -638,7 +639,7 @@ func TestRoot_searchHighlight(t *testing.T) {
 		t.Run(tt.name, func(t *testing.T) {
 			root := sectionHeader1Helper(t)
 
-			line := root.Doc.getLineC(tt.args.lineNum, root.Doc.TabWidth)
+			line := root.Doc.getLineC(tt.args.lineNum)
 			root.searcher = tt.fields.searcher
 			root.StyleSearchHighlight = OVStyle{Reverse: true}
 			root.searchHighlight(line)
@@ -679,7 +680,7 @@ func TestRoot_columnDelimiterHighlight(t *testing.T) {
 			name: "Test columnDelimiterHighlight1",
 			fields: fields{
 				columnDelimiter: "|",
-				columnCursor:    0,
+				columnCursor:    1,
 			},
 			args: args{
 				lineNum: 2,
@@ -693,7 +694,7 @@ func TestRoot_columnDelimiterHighlight(t *testing.T) {
 			name: "Test columnDelimiterHighlight2",
 			fields: fields{
 				columnDelimiter: "|",
-				columnCursor:    1,
+				columnCursor:    2,
 			},
 			args: args{
 				lineNum: 2,
@@ -707,7 +708,7 @@ func TestRoot_columnDelimiterHighlight(t *testing.T) {
 			name: "Test columnDelimiterHighlight3",
 			fields: fields{
 				columnDelimiter: "|",
-				columnCursor:    2,
+				columnCursor:    3,
 			},
 			args: args{
 				lineNum: 2,
@@ -721,7 +722,7 @@ func TestRoot_columnDelimiterHighlight(t *testing.T) {
 			name: "Test columnDelimiterHighlight4",
 			fields: fields{
 				columnDelimiter: "|",
-				columnCursor:    3,
+				columnCursor:    4,
 			},
 			args: args{
 				lineNum: 0,
@@ -740,7 +741,7 @@ func TestRoot_columnDelimiterHighlight(t *testing.T) {
 			m.ColumnDelimiterReg = condRegexpCompile(m.ColumnDelimiter)
 			m.columnCursor = tt.fields.columnCursor
 			root.StyleColumnHighlight = OVStyle{Bold: true}
-			line := root.Doc.getLineC(tt.args.lineNum, root.Doc.TabWidth)
+			line := root.Doc.getLineC(tt.args.lineNum)
 			root.columnDelimiterHighlight(line)
 			if line.str != tt.want.str {
 				t.Errorf("\nline: %v\nwant: %v\n", line.str, tt.want.str)
@@ -813,7 +814,7 @@ func TestRoot_columnWidthHighlight(t *testing.T) {
 			m.setColumnWidths()
 			t.Log(m.columnWidths)
 			m.columnCursor = tt.fields.columnCursor
-			line := root.Doc.getLineC(tt.args.lineNum, root.Doc.TabWidth)
+			line := root.Doc.getLineC(tt.args.lineNum)
 			root.columnWidthHighlight(line)
 			if line.str != tt.want.str {
 				t.Errorf("\nline: %v\nwant: %v\n", line.str, tt.want.str)
@@ -849,9 +850,10 @@ func TestRoot_sectionNum(t *testing.T) {
 
 func Test_findColumnEnd(t *testing.T) {
 	type args struct {
-		str string
-		pos []int
-		n   int
+		str   string
+		pos   []int
+		n     int
+		start int
 	}
 	tests := []struct {
 		name string
@@ -861,99 +863,110 @@ func Test_findColumnEnd(t *testing.T) {
 		{
 			name: "Test findColumnEnd1Over",
 			args: args{
-				str: "012345678901234567890123",
-				pos: []int{7, 15},
-				n:   0,
+				str:   "012345678901234567890123",
+				pos:   []int{7, 15},
+				n:     0,
+				start: 0,
 			},
 			want: 24,
 		},
 		{
 			name: "Test findColumnEnd2",
 			args: args{
-				str: "header1 header2 header3",
-				pos: []int{7, 15},
-				n:   0,
+				str:   "header1 header2 header3",
+				pos:   []int{7, 15},
+				n:     0,
+				start: 0,
 			},
 			want: 7,
 		},
 		{
 			name: "Test findColumnEnd3",
 			args: args{
-				str: "1       2       3",
-				pos: []int{7, 15},
-				n:   0,
+				str:   "1       2       3",
+				pos:   []int{7, 15},
+				n:     0,
+				start: 0,
 			},
 			want: 7,
 		},
 		{
 			name: "Test findColumnEnd4",
 			args: args{
-				str: "     1       2        3",
-				pos: []int{7, 15},
-				n:   0,
+				str:   "     1       2        3",
+				pos:   []int{7, 15},
+				n:     0,
+				start: 0,
 			},
 			want: 7,
 		},
 		{
 			name: "Test findColumnEnd6Over1",
 			args: args{
-				str: "123   456789012 345678901234",
-				pos: []int{7, 15},
-				n:   0,
+				str:   "123   456789012 345678901234",
+				pos:   []int{7, 15},
+				n:     0,
+				start: 0,
 			},
 			want: 5,
 		},
 		{
 			name: "Test findColumnEnd6Over2",
 			args: args{
-				str: "123   456789012 345678901234",
-				pos: []int{7, 15},
-				n:   1,
+				str:   "123   456789012 345678901234",
+				pos:   []int{7, 15},
+				n:     1,
+				start: 6,
 			},
 			want: 15,
 		},
 		{
 			name: "Test findColumnEnd7Over1",
 			args: args{
-				str: "abedefghi jkujik mnoopqr",
-				pos: []int{7, 15},
-				n:   0,
+				str:   "abedefghi jkujik mnoopqr",
+				pos:   []int{7, 15},
+				n:     0,
+				start: 0,
 			},
 			want: 9,
 		},
 		{
 			name: "Test findColumnEnd7Over2",
 			args: args{
-				str: "abedefghi jkujikl mnoopqr",
-				pos: []int{7, 15},
-				n:   1,
+				str:   "abedefghi jkujikl mnoopqr",
+				pos:   []int{7, 15},
+				n:     1,
+				start: 0,
 			},
 			want: 17,
 		},
 		{
 			name: "Test findColumnEnd8Over1",
 			args: args{
-				str: "abedefghi jkujikl mnoopqr",
-				pos: []int{7, 15},
-				n:   0,
+				str:   "abedefghi jkujikl mnoopqr",
+				pos:   []int{7, 15},
+				n:     0,
+				start: 0,
 			},
 			want: 9,
 		},
 		{
 			name: "Test findColumnEnd8Over2",
 			args: args{
-				str: "あいうえお かきくけこ さしすせそ",
-				pos: []int{7, 15},
-				n:   1,
+				str:   "あいうえお かきくけこ さしすせそ",
+				pos:   []int{10, 15},
+				n:     1,
+				start: 10,
 			},
 			want: 21,
 		},
 		{
 			name: "Test findColumnEnd9Over",
 			args: args{
-				str: "abedefg hijkujiklmnoopqrstuvxyz",
-				pos: []int{7, 15},
-				n:   1,
+				str:   "abedefg hijkujiklmnoopqrstuvxyz",
+				pos:   []int{7, 15},
+				n:     1,
+				start: 7,
 			},
 			want: 31,
 		},
@@ -961,7 +974,7 @@ func Test_findColumnEnd(t *testing.T) {
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			lc := StrToContents(tt.args.str, 8)
-			if got := findColumnEnd(lc, tt.args.pos, tt.args.n); got != tt.want {
+			if got := findColumnEnd(lc, tt.args.pos, tt.args.n, tt.args.start); got != tt.want {
 				t.Errorf("findColumnEnd() = %v, want %v", got, tt.want)
 			}
 		})
@@ -1069,3 +1082,216 @@ func TestRoot_sectionHeader(t *testing.T) {
 		})
 	}
 }
+
+func TestRoot_setAlignConverter(t *testing.T) {
+	tcellNewScreen = fakeScreen
+	defer func() {
+		tcellNewScreen = tcell.NewScreen
+	}()
+	type fields struct {
+		fileName        string
+		header          int
+		columnWidth     bool
+		columnDelimiter string
+	}
+	tests := []struct {
+		name   string
+		fields fields
+		want   []int
+	}{
+		{
+			name: "Test setAlignConverter1",
+			fields: fields{
+				fileName:    "width-column.txt",
+				header:      1,
+				columnWidth: true,
+			},
+			want: []int{3, 5},
+		},
+		{
+			name: "Test setAlignConverterDelimiter",
+			fields: fields{
+				fileName:        "column.txt",
+				header:          1,
+				columnWidth:     false,
+				columnDelimiter: "|",
+			},
+			want: []int{0, 7, 7, 7},
+		},
+		{
+			name: "Test setAlignConverterDelimiter2",
+			fields: fields{
+				fileName:        "test.csv",
+				header:          1,
+				columnWidth:     false,
+				columnDelimiter: ",",
+			},
+			want: []int{1, 5, 1},
+		},
+		{
+			name: "Test setAlignNoColumn",
+			fields: fields{
+				fileName:    "test.txt",
+				header:      1,
+				columnWidth: true,
+			},
+			want: []int{},
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			root := rootFileReadHelper(t, filepath.Join(testdata, tt.fields.fileName))
+			m := root.Doc
+			m.width = 80
+			root.scr.vHeight = 24
+			m.topLX = 0
+			m.Header = tt.fields.header
+			m.ColumnMode = true
+			m.ColumnWidth = tt.fields.columnWidth
+			m.ColumnDelimiter = tt.fields.columnDelimiter
+			if m.ColumnDelimiter != "" {
+				m.ColumnDelimiterReg = condRegexpCompile(m.ColumnDelimiter)
+			}
+			root.scr.lines = make(map[int]LineC)
+			root.prepareScreen()
+			ctx := context.Background()
+			root.Doc.ColumnRainbow = true
+			root.Doc.Converter = convAlign
+			root.Doc.alignConv = newAlignConverter(true)
+			root.prepareDraw(ctx)
+			if got := root.Doc.alignConv.maxWidths; !reflect.DeepEqual(got, tt.want) {
+				t.Errorf("Root.setAlignConverter() = %#v, want %#v", got, tt.want)
+			}
+		})
+	}
+}
+
+func Test_maxWidthsDelm(t *testing.T) {
+	type args struct {
+		maxWidths    []int
+		delimiter    string
+		delimiterReg *regexp.Regexp
+	}
+	tests := []struct {
+		name string
+		str  string
+		args args
+		want []int
+	}{
+		{
+			name: "Test maxWidthsDelm1",
+			str:  "a, b, c, d, e, f, g",
+			args: args{
+				maxWidths:    []int{0, 0, 0, 0, 0},
+				delimiter:    ",",
+				delimiterReg: regexpCompile(",", false),
+			},
+			want: []int{1, 2, 2, 2, 2, 2},
+		},
+		{
+			name: "Test maxWidthsDelm2",
+			str:  "no delimiter",
+			args: args{
+				maxWidths:    []int{2, 2, 2, 2, 2, 2},
+				delimiter:    ",",
+				delimiterReg: regexpCompile(",", false),
+			},
+			want: []int{2, 2, 2, 2, 2, 2},
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			lc := StrToContents(tt.str, 8)
+			if got := maxWidthsDelm(lc, tt.args.maxWidths, tt.args.delimiter, tt.args.delimiterReg); !reflect.DeepEqual(got, tt.want) {
+				t.Errorf("maxWidthsDelm() = %v, want %v", got, tt.want)
+			}
+		})
+	}
+}
+
+func Test_maxWidthsWidth(t *testing.T) {
+	type args struct {
+		maxWidths []int
+		widths    []int
+		addRight  []int
+	}
+	tests := []struct {
+		name  string
+		str   string
+		args  args
+		want  []int
+		want2 []int
+	}{
+		{
+			name: "Test maxWidthsWidth1",
+			str:  " 1   tsst        21",
+			args: args{
+				maxWidths: []int{0},
+				widths:    []int{2, 11},
+				addRight:  []int{0, 0},
+			},
+			want:  []int{1, 4},
+			want2: []int{0, 0},
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			lc := StrToContents(tt.str, 8)
+			got, got2 := maxWidthsWidth(lc, tt.args.maxWidths, tt.args.widths, tt.args.addRight)
+			if !reflect.DeepEqual(got, tt.want) {
+				t.Errorf("maxWidthsWidth() = %v, want %v", got, tt.want)
+			}
+			if !reflect.DeepEqual(got2, tt.want2) {
+				t.Errorf("maxWidthsWidth() addRight = %v, want %v", got2, tt.want2)
+			}
+		})
+	}
+}
+
+func Test_trimWidth(t *testing.T) {
+	type args struct {
+		lc contents
+	}
+	tests := []struct {
+		name      string
+		args      args
+		want      int
+		wantRight int
+	}{
+		{
+			name: "Test trimLC1",
+			args: args{
+				lc: StrToContents("test", 8),
+			},
+			want:      4,
+			wantRight: 0,
+		},
+		{
+			name: "Test trimLC2",
+			args: args{
+				lc: StrToContents("    test   ", 8),
+			},
+			want:      4,
+			wantRight: 1,
+		},
+		{
+			name: "Test trimLC3",
+			args: args{
+				lc: StrToContents("    123.0 ", 8),
+			},
+			want:      5,
+			wantRight: 1,
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			got, gotLeft := trimWidth(tt.args.lc)
+			if got != tt.want {
+				t.Errorf("trimLC() got = %v, want %v", got, tt.want)
+			}
+			if gotLeft != tt.wantRight {
+				t.Errorf("trimLC() gotLeft = %v, want %v", gotLeft, tt.wantRight)
+			}
+		})
+	}
+}
